Developer’s Guide — Schematics 0.9.2 documentation

### Navigation

- index
- modules |
- Schematics 0.9.2 documentation »

# Developer’s Guide

Schematics development is lead by James Dennis, but this project is very much a sum of the work done by a community.

## List of Contributors

    $ cd schematics
    $ git shortlog -sn

Schematics has a few design choices that are both explicit and implicit. We care about these decisions and have probably debated them on the mailing list. We ask that you honor those and make them known in this document.

## Get the code

Please see the Installing from Github section of the Install Guide page for details on how to obtain the Schematics source code.

## Tests

Using py.test

    $ py.test tests/

## Writing Documentation

Documentation is essential to helping other people understand, learn, and use Schematics. We would appreciate any help you can offer in contributing documentation to our project.

Schematics uses the .rst (reStructuredText) format for all of our documentation. You can read more about .rst on the reStructuredText Primer page.

## Installing Documentation

Just as you verify your code changes in your local environment before committing, you should also verify that your documentation builds and displays properly on your local environment.

First, install Sphinx:

    $ pip install sphinx

Next, run the Docs builder:

    $ cd docs
    $ make html

The docs will be placed in the ./_build folder and you can view them from any standard web browser. (Note: the ./_build folder is included in the .gitignore file to prevent the compiled docs from being included with your commits).

Each time you make changes and want to see them, re-run the Docs builder and refresh the page.

Once the documentation is up to your standards, go ahead and commit it. As with code changes, please be descriptive in your documentation commit messages as it will help others understand the purpose of your adjustment.

### Navigation

- index
- modules |
- Schematics 0.9.2 documentation »